@@ -13,11 +13,12 @@ to you infrastructure
 """
 
 import sys
+import os.path
 from optparse import Option
 
-from .exceptions import InvalidCommand
-from .colors import blue, red
-from .utils import indent
+from commandor.exceptions import InvalidCommand
+from commandor.colors import blue
+from commandor.utils import indent
 
 
 __all__ = 'Command', 'Commandor'
@@ -50,6 +51,12 @@ class Mixin(object):
         """
         print(s)
 
+    def abort(self, s):
+        """Display and exit
+        """
+        self.display(s)
+        self.exit()
+
 
 class CommandMetaClass(type):
     """Command meta class
@@ -105,6 +112,7 @@ class Commandor(Mixin):
         self.parser = parser
         self._args = args
         self._options = options
+        self._curdir = None
 
     def add_parser_option(self, option):
         """Add option to parser
@@ -136,6 +144,8 @@ class Commandor(Mixin):
     def process(self):
         """Process parsing
         """
+
+        self._curdir = os.path.abspath(os.path.curdir)
         self._options, self._args = self.parse_args()
 
         if not self._args:
@@ -146,8 +156,7 @@ class Commandor(Mixin):
 
         command, args = self.__class__.find_command(self._args)
         command_instance = command(self.parser, self._args, self._options)
-
-        command_instance.run(args)
+        command_instance.run(self._curdir, *args)
 
 
     @classmethod
